==> wallgen-0.9.1-src.tar.gz: src/main/java/ca/quadrilateral/wallgenerator/Controller.java <==
/*
Copyright 2011 Daniel Morton. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are
permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this list of
      conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice, this list
      of conditions and the following disclaimer in the documentation and/or other materials
      provided with the distribution.

THIS SOFTWARE IS PROVIDED BY Daniel Morton ''AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the
authors and should not be interpreted as representing official policies, either expressed
or implied, of Daniel Morton.
*/

package ca.quadrilateral.wallgenerator;

import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Map;

import javax.imageio.ImageIO;

public class Controller {
    private Map<String, BufferedImage> generatedImages = null;
    private FileChooserPanel fileChooserPanel = null;
    private OptionPanel optionPanel = null;
    private ConfigManager configManager = null;

    public Controller(final FileChooserPanel fileChooserPanel, final OptionPanel optionPanel, final ConfigManager configManager) {
        this.configManager = configManager;
        this.optionPanel = optionPanel;
        this.fileChooserPanel = fileChooserPanel;
        this.optionPanel.addChangeGenerationSettingsListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                clearGeneratedImages();
                updateCurrentGenerationValuesInFileChooserPanel();
            }
        });

        this.fileChooserPanel.addChangeGenerationSettingsListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                clearGeneratedImages();
            }
        });
        
        updateCurrentGenerationValuesInFileChooserPanel();
    }
    
    private void updateCurrentGenerationValuesInFileChooserPanel() {
        fileChooserPanel.setCurrentResolution(optionPanel.getSelectedResolution());
        fileChooserPanel.setCurrentOutputFormat(optionPanel.getSelectedOutputType());    	
    }

    public void generateOutput() throws FileNotFoundException, IOException {
        if (!hasImages()) {
            fetchImages();
        }

        final Config config = this.configManager.getConfig(this.optionPanel.getSelectedResolution());
        final OutputConfig outputConfig = config.getOutputConfig(optionPanel.getSelectedOutputType());

        final OutputGenerator generator = new OutputGeneratorFactory().createOutputGenerator(outputConfig);
        generator.generate(
        		outputConfig, 
        		fileChooserPanel.getTargetDirectory(), 
        		fileChooserPanel.outputFileNameBase(), 
        		optionPanel.getSelectedFileType(), 
        		this.generatedImages,
        		optionPanel.useTransparency());
    }

    public BufferedImage generatePreview() throws FileNotFoundException, IOException {
        if (!hasImages()) {
            fetchImages();
        }

        final int previewImageHeight = calculatePreviewImageHeight();
        final int previewImageWidth = calculatePreviewImageWidth();

        final BufferedImage previewImage = new BufferedImage(previewImageWidth, previewImageHeight, BufferedImage.TYPE_INT_ARGB);
        final Graphics2D graphics = previewImage.createGraphics();

        int drawPosition = 0;

        drawPosition += drawPreviewImagePortion(graphics, "CloseLeft", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "CloseFront", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "NearLeft", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "NearFront", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "FarLeft", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "FarFront", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "FarRight", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "NearRight", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "CloseRight", drawPosition, previewImageHeight, 0);

        graphics.dispose();

        return previewImage;
    }

    private int drawPreviewImagePortion(Graphics2D graphics, String key, int drawPosition, int previewImageHeight, int verticalOffset) {
        final BufferedImage image = (BufferedImage)generatedImages.get(key);

        final int height = ((previewImageHeight - image.getHeight()) / 2) + verticalOffset;

        graphics.drawImage(image, drawPosition, height, null);
        return image.getWidth();
    }

    private int calculatePreviewImageHeight() {
        int maxHeight = 0;

        for(Image image : this.generatedImages.values()) {
            int imageHeight = ((BufferedImage)image).getHeight();
            if (imageHeight > maxHeight) {
                maxHeight = imageHeight;
            }
        }

        return maxHeight;
    }

    private int calculatePreviewImageWidth() {
        int width = 0;
        width += (((BufferedImage)this.generatedImages.get("CloseLeft")).getWidth() * 2);
        width += ((BufferedImage)this.generatedImages.get("CloseFront")).getWidth();
        width += (((BufferedImage)this.generatedImages.get("NearLeft")).getWidth() * 2);
        width += ((BufferedImage)this.generatedImages.get("NearFront")).getWidth();
        width += (((BufferedImage)this.generatedImages.get("FarLeft")).getWidth() * 2);
        width += ((BufferedImage)this.generatedImages.get("FarFront")).getWidth();

        return width;
    }

    private boolean hasImages() {
        return this.generatedImages != null;
    }

    private void fetchImages() throws FileNotFoundException, IOException {
        final File sourceFile = fileChooserPanel.getSourceFile();
        if (sourceFile == null) {
            throw new FileNotFoundException("Source File");
        }

        final BufferedImage sourceImage = ImageIO.read(sourceFile);

        this.generatedImages = new Generator(chooseConfig(), optionPanel.getNearWallDarkening(), optionPanel.getFarWallDarkening()).generate(sourceImage);
    }

    private Config chooseConfig() {
        final String resolution = optionPanel.getSelectedResolution();
        return this.configManager.getConfig(resolution);
    }

    public void clearGeneratedImages() {
        this.generatedImages = null;
    }
}

==> wallgen-0.9.2-src.tar.gz: src/main/java/ca/quadrilateral/wallgenerator/Controller.java <==
/*
Copyright 2011 Daniel Morton. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are
permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this list of
      conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice, this list
      of conditions and the following disclaimer in the documentation and/or other materials
      provided with the distribution.

THIS SOFTWARE IS PROVIDED BY Daniel Morton ''AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the
authors and should not be interpreted as representing official policies, either expressed
or implied, of Daniel Morton.
*/

package ca.quadrilateral.wallgenerator;

import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Map;

import javax.imageio.ImageIO;

public class Controller {
    private Map<String, BufferedImage> generatedImages = null;
    private FileChooserPanel fileChooserPanel = null;
    private OptionPanel optionPanel = null;
    private ConfigManager configManager = null;

    public Controller(final FileChooserPanel fileChooserPanel, final OptionPanel optionPanel, final ConfigManager configManager) {
        this.configManager = configManager;
        this.optionPanel = optionPanel;
        this.fileChooserPanel = fileChooserPanel;
        this.optionPanel.addChangeGenerationSettingsListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                clearGeneratedImages();
                updateCurrentGenerationValuesInFileChooserPanel();
            }
        });

        this.fileChooserPanel.addChangeGenerationSettingsListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                clearGeneratedImages();
            }
        });
        
        updateCurrentGenerationValuesInFileChooserPanel();
    }
    
    private void updateCurrentGenerationValuesInFileChooserPanel() {
        fileChooserPanel.setCurrentResolution(optionPanel.getSelectedResolution());
        fileChooserPanel.setCurrentOutputFormat(optionPanel.getSelectedOutputType());    	
    }

    public void generateOutput() throws FileNotFoundException, IOException {
        if (!hasImages()) {
            fetchImages();
        }

        final Config config = this.configManager.getConfig(this.optionPanel.getSelectedResolution());
        final OutputConfig outputConfig = config.getOutputConfig(optionPanel.getSelectedOutputType());

        final OutputGenerator generator = new OutputGeneratorFactory().createOutputGenerator(outputConfig);
        generator.generate(
        		outputConfig, 
        		fileChooserPanel.getTargetDirectory(), 
        		fileChooserPanel.outputFileNameBase(), 
        		optionPanel.getSelectedFileType(), 
        		this.generatedImages,
        		optionPanel.useTransparency());
    }

    public BufferedImage generatePreview() throws FileNotFoundException, IOException {
        if (!hasImages()) {
            fetchImages();
        }

        final int previewImageHeight = calculatePreviewImageHeight();
        final int previewImageWidth = calculatePreviewImageWidth();

        final BufferedImage previewImage = new BufferedImage(previewImageWidth, previewImageHeight, BufferedImage.TYPE_INT_ARGB);
        final Graphics2D graphics = previewImage.createGraphics();

        int drawPosition = 0;

        drawPosition += drawPreviewImagePortion(graphics, "CloseLeft", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "CloseFront", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "NearLeft", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "NearFront", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "FarLeft", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "FarFront", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "FarRight", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "NearRight", drawPosition, previewImageHeight, 0);
        drawPosition += drawPreviewImagePortion(graphics, "CloseRight", drawPosition, previewImageHeight, 0);

        graphics.dispose();

        return previewImage;
    }

    private int drawPreviewImagePortion(Graphics2D graphics, String key, int drawPosition, int previewImageHeight, int verticalOffset) {
        final BufferedImage image = (BufferedImage)generatedImages.get(key);

        final int height = ((previewImageHeight - image.getHeight()) / 2) + verticalOffset;

        graphics.drawImage(image, drawPosition, height, null);
        return image.getWidth();
    }

    private int calculatePreviewImageHeight() {
        int maxHeight = 0;

        for(Image image : this.generatedImages.values()) {
            int imageHeight = ((BufferedImage)image).getHeight();
            if (imageHeight > maxHeight) {
                maxHeight = imageHeight;
            }
        }

        return maxHeight;
    }

    private int calculatePreviewImageWidth() {
        int width = 0;
        width += (((BufferedImage)this.generatedImages.get("CloseLeft")).getWidth() * 2);
        width += ((BufferedImage)this.generatedImages.get("CloseFront")).getWidth();
        width += (((BufferedImage)this.generatedImages.get("NearLeft")).getWidth() * 2);
        width += ((BufferedImage)this.generatedImages.get("NearFront")).getWidth();
        width += (((BufferedImage)this.generatedImages.get("FarLeft")).getWidth() * 2);
        width += ((BufferedImage)this.generatedImages.get("FarFront")).getWidth();

        return width;
    }

    private boolean hasImages() {
        return this.generatedImages != null;
    }

    private void fetchImages() throws FileNotFoundException, IOException {
        final File sourceFile = fileChooserPanel.getSourceFile();
        if (sourceFile == null) {
            throw new FileNotFoundException("Source File");
        }

        final BufferedImage sourceImage = ImageIO.read(sourceFile);

        this.generatedImages = new Generator(chooseConfig(), optionPanel.getPostProcessingConfig()).generate(sourceImage);
    }

    private Config chooseConfig() {
        final String resolution = optionPanel.getSelectedResolution();
        return this.configManager.getConfig(resolution);
    }

    public void clearGeneratedImages() {
        this.generatedImages = null;
    }
}
